Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(256)

Unified Diff: ash/wm/panels/panel_layout_manager.cc

Issue 2871813002: Converts remaining usage of WmLayoutManager to aura::LayoutManager (Closed)
Patch Set: cleanup Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/wm/panels/panel_layout_manager.h ('k') | ash/wm/root_window_layout_manager.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/wm/panels/panel_layout_manager.cc
diff --git a/ash/wm/panels/panel_layout_manager.cc b/ash/wm/panels/panel_layout_manager.cc
index aaedc7c3a29ebf1e38e10da9b7cff5dd053a614f..81f8fe83fdd86f4cbac840ecd68f4dd17cddc6ed 100644
--- a/ash/wm/panels/panel_layout_manager.cc
+++ b/ash/wm/panels/panel_layout_manager.cc
@@ -337,7 +337,7 @@ views::Widget* PanelLayoutManager::GetCalloutWidgetForPanel(WmWindow* panel) {
}
////////////////////////////////////////////////////////////////////////////////
// PanelLayoutManager, WmLayoutManager implementation:
void PanelLayoutManager::OnWindowResized() {
Relayout();
}
@@ -458,11 +458,12 @@ void PanelLayoutManager::OnShelfAlignmentChanged(WmWindow* root_window) {
Relayout();
}
-void PanelLayoutManager::OnVirtualKeyboardStateChanged(bool activated,
- WmWindow* root_window) {
- UpdateKeyboardObserverFromStateChanged(activated, root_window,
- panel_container_->GetRootWindow(),
- &keyboard_observer_);
+void PanelLayoutManager::OnVirtualKeyboardStateChanged(
+ bool activated,
+ aura::Window* root_window) {
+ UpdateKeyboardObserverFromStateChanged(
+ activated, root_window, panel_container_->GetRootWindow()->aura_window(),
+ &keyboard_observer_);
}
/////////////////////////////////////////////////////////////////////////////
« no previous file with comments | « ash/wm/panels/panel_layout_manager.h ('k') | ash/wm/root_window_layout_manager.h » ('j') | no next file with comments »
@@ -337,7 +337,7 @@ views::Widget* PanelLayoutManager::GetCalloutWidgetForPanel(WmWindow* panel) {
}
////////////////////////////////////////////////////////////////////////////////
-// PanelLayoutManager, WmLayoutManager implementation:
+// PanelLayoutManager, aura::LayoutManager implementation:
void PanelLayoutManager::OnWindowResized() {
Relayout();

Powered by Google App Engine
This is Rietveld 408576698